@@ -19,13 +19,13 @@
 */
 
 #include "config_two.h"
+#include "lskat_debug.h"
 
 // Qt includes
 
 // KDE includes
-#include <kdebug.h>
-#include <kconfiggroup.h>
-#include <klocale.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
 
 // Constructor for the configuration
 ConfigTwo::ConfigTwo(QObject *parent)
@@ -75,7 +75,7 @@ void ConfigTwo::save(KConfig *cfg)
         it.next();
         Player *player = it.value();
         int no = it.key();
-        KConfigGroup playercfg = cfg->group(QString::fromLatin1("LSkat_Player%1").arg(no));
+        KConfigGroup playercfg = cfg->group(QStringLiteral("LSkat_Player%1").arg(no));
         player->save(playercfg);
     }
 }
@@ -98,7 +98,7 @@ void ConfigTwo::load(KConfig *cfg)
         it.next();
         Player *player = it.value();
         int no = it.key();
-        KConfigGroup playercfg = cfg->group(QString::fromLatin1("LSkat_Player%1").arg(no));
+        KConfigGroup playercfg = cfg->group(QStringLiteral("LSkat_Player%1").arg(no));
         player->load(playercfg);
     }
 }
@@ -129,5 +129,3 @@ void ConfigTwo::setInputType(int no, InputDeviceType type)
     mInputTypes[no] = type;
     emit signalInputType(no, type);
 }
-
-#include "config_two.moc"
